clc

clear;



global  PP D EM S Concentration



%   T = Total Time horizon(year)

    T = 50;

    

%   POWER PLANTS



    % number of technologies

        n = 8;

        % 1: Coal (Single Unit Advanced PC)

        % 2: Natural Gas (Conventional CC)

        % 3: Nuclear

        % 4: Solar PV

        % 5: Wind (Onshore)

        % 6: Solar Thermal

        % 7: CCS (Coal Single Unit Advanced PC with CCS)

        % 8: Hydro



    PP = zeros(n, 12);    

    % Power generation options

        % PP(i, 1): Capital cost ($/KW)

        % PP(i, 2): Fixed O&M cost ($/KW)

        % PP(i, 3): Variable O&M cost ($/MWh)

        % PP(i, 4): Construction period (Lead time) (year)

        % PP(i, 5): Operation period (year)

        % PP(i, 6): Construction Emission CO2 (ton/MW)

        % PP(i, 7): Construction Emission CH4 (ton/MW)

        % PP(i, 8): Construction Emission N2O (ton/MW)

        % PP(i, 9): Operation Emission CO2 (ton/MW/year)

        % PP(i, 10): Operation Emission CH4 (ton/MW/year)

        % PP(i, 11): Operation Emission N2O (ton/MW/year)

        % PP(i, 12): Heat Rate (Btu/kWh)

      

        PP(:, 1) = [3246 917 5530 3873 2213 5067 5227 2936];

        PP(:, 2) = [37.8 13.17 93.28 24.69 39.55 67.26 80.53 14.13];

        PP(:, 3) = [4.47 3.60 2.14+5.6 0 0 0 9.51 0];

        PP(:, 4) = [4 3 5 2 4 2 4 4];

        PP(:, 5) = [40 30 35 20 30 20 40 100];

        PP(:, 6) = [202 762 36700 17400 32500 37300 4630 788];

        PP(:, 7) = [0.006171 0 0 0.533 0 0 0 0.0578];

        PP(:, 8) = [0.009344 0 0 0.478 0 0 0 0.0451];

        PP(:, 9) = [6590 5300 666 0 0 0 1750 0];

        PP(:, 10) = [1.21 0 0 0 0 0 13.2 0];

        PP(:, 11) = [0.582422 0 0 0 0 0 7.36 0];

        PP(:, 12) = [8800 7050 0 0 0 0 12000 0];

        

        % EIA - International Energy Outlook 2013

        EIA = xlsread('EIA.xlsx');

        % Net Capacity

        D = EIA(1:8, :)/0.00876;

        CapFac = EIA(9:16, :);



%	CONCENTRATIONS

    % Concentration(i, 1): CO2 concentration (ton)

    % Concentration(i, 2): CH4 concentration (ton)

    % Concentration(i, 3): N2O concentration (ton)

  

    E_CONC = zeros(3, T);

    Concentration = zeros(3, T);

    for i = 0:1:T - 1

        j = i + 1;

        Concentration(1, j) = 0.217 + 0.259 * exp(-i / 172.9) + 0.338 * exp(-i / 18.51) + 0.186 * exp (-i/ 1.186);

        Concentration(2, j) = exp(-i / 12);  

        Concentration(3, j) = exp(-i / 114);

    end



%	EMISSIONS

    % Em(1, i): CO2 emissions from Electricity sources(Mt)

    % Em(2, i): CH4 emissions from Electricity sources(Mt)

    % EM(3, i): N2O emissions from Electricity sources(Mt)

        % Global Warming Potential (GWP): 

        % http://www.ipcc.ch/publications_and_data/ar4/wg1/en/tssts-2-5.html

        % CH4 GWP = 25 (for 100 years)

        % N2O GWP =  298 (for 100 years)

    EM = zeros (3, T);

    

%   STATE SPACE

    % S: State

        % 1:n Under_Construction Capacity New

        % n+1:2n Under_Construction Capacity Old

        % 2n+1:3n Operating Capacity New

        % 3n+1:4n Operating Capacity Old

        % 4n+1:5n Total built capacity (gross)

        % 5n+1 Atmospheric Temperature "Tat" at time t

        S = zeros(5 * n + 1, T);

    % Initial State        

        S(1 + 2 * n:3 * n, 1) = max(1, D(:, 1));

        % Installed Capacity: 

          % Solar, Wind, Hydro: http://www.worldenergy.org/data/resources/

          % Nuclear: http://www.world-nuclear.org/info/Facts-and-Figures/World-Nuclear-Power-Reactors-and-Uranium-Requirements/

          % Coal: http://www.iea-etsap.org/web/E-TechDS/PDF/E01-coal-fired-power-GS-AD-gct.pdf

          % Natural Gas: 

        S(1 + 4 * n:5 * n, 1) = [3e6 1e5 4e5 8.0e4 3.3e5 1 1 1.3e6];

        

%   ACTION SPACE

    Action = zeros(n, T);  

    

%   Costs

    % Discount rate

    lambda = 1/(1+0.05);

    % Fuel Costs

    F = xlsread('Fuel.xlsx');

    F = F(2:end, 2:end);

    % Construction, O&M, and Fuel Costs

    CST = zeros(n, 4, T);

        % Construction Costs

        CCON = zeros(n, T);

        % Fixed Operation Costs

        CFOP = zeros(n, T);

        % Variable Operation Costs

        CVOP = zeros(n, T);

        % Fuel Costs

        CF = zeros(n, T); 

    % Generation and Emission Costs

    Cost = zeros(2, T);



for t = 1:1:T

NOC = zeros(n, 1);

OOC = zeros(n, 1);

GOC = zeros(n, 1);

NCC = zeros(n, 1);

OCC = zeros(n, 1);





%   Operating Capacity MW

    % New Net Operating Capacity at time (NOC) without x3

    % OLd Net Operating Capacity at time (OOC)

    % Gross Net Operating Capacity at (GOC)

    % Electricity Deficit (EDEF)

    % Electricity Required at time t (EREQ)

    xdate = max(0, t + 1 - PP(:, 4));

    odate = max(0, t + 1 - PP(:, 5));

    for i=1:1:n

        for j=t-1:-1:max(xdate(i), 1)

            NOC(i) = NOC(i) + S(i, j) / PP(i, 4);

        end

        for j=t:-1:odate(i)+ 1

            jj = t + 1 - j;

            OOC(i) = OOC(i) + ((S(2 * n + i, j)) * (1 - jj / PP(i, 5)));

        end

        % OLd Net Operating Capacity at time t+1

        S(3 * n + 1:4 * n, t + 1) = OOC;

        % Gross Net Operating Capacity at time t+1 

        GOC(i) = NOC(i) + OOC(i);

    end



    % Electricity Deficit at time t+1

    EDEF = max(0, D(:, t + 1) - GOC);

    % Electricity Required at time t

    EREQ = EDEF.*(PP(:, 4));      

 

%   Construction Capacity MW

    % New Construction Capacity(NCC)

    % OLd Construction Capacity(OCC)

    if EDEF == 0

        Action(:, t) = 0;

    else

        Action(:, t) = EREQ./sum(EREQ);

    end

    NCC = EREQ;

    % New Construction Capacity at time t

    S(1:n, t) = NCC;

    

    for i=1:1:n

        for j=t:-1:xdate(i)+1

            jj = t + 1 - j;

            OCC(i) = OCC(i) + (((PP(i, 4) - jj) / PP(i, 4)) * S(i, j));

        end

        % Old Construction Capacity at time t+1

        S(n + i, t + 1) = OCC(i);

    end

   

% New Net Operating Capacity at time t+1

S(2 * n + 1:3 * n, t + 1) = NOC + (NCC./(PP(:, 4)));



%   TOTAL CAPACITY

    % Total Net Construction Capacity at time t

    CONCAP = S(1:n, t) + S(n + 1:2 * n, t);

    % Total Net Operating Capacity at time t

    OPCAP = S(2 * n + 1:3 * n, t) + S(3 * n + 1:4 * n, t);

    % Total Net Operating Capacity at time t + 1

    OPCAP2 = S(2 * n + 1:3 * n, t + 1) + S(3 * n + 1:4 * n, t + 1);

    % Total built Capacity at time t + 1

    S(4 * n + 1:5 * n, t + 1) = S(4 * n + 1:5 * n, t) + OPCAP2./CapFac(:, t + 1);   

    

%	Emissions (Million tons)

    for i = 1:1:3

        CEM = CONCAP.*(PP(:, 5 + i)./PP(:, 4));

        OEM = OPCAP.*PP(:, 8 + i);

        EM(i, t)  = (sum(CEM + OEM))/ 1e6;

    end



    % Emission Concentraition at time t (Mt)

    E_CONC(:, t) = CONC(t);



    % Radiative Forcing at time t (W/m2)

    deltaF = FORCE(E_CONC(:, t));



    % Atmospheric Temperature

    S(5 * n + 1, t + 1) = TEMP(S(5 * n + 1, t), deltaF);



% Cost (Billion$)



    % Electricity Cost  (Billion$)

        % Construction Cost

        CST(:, 1, t) = (CONCAP.*(PP(:, 1)./CapFac(:, t))) / 1e6;

        % Fixed O&M Cost

        CST(:, 2, t) = (OPCAP.*(PP(:, 2)./CapFac(:, t))) / 1e6;

        % Variable O&M Cost

        CST(:, 3, t) = (OPCAP.*PP(:, 3))* 365 * 24 / 1e9;

        % Fuel Cost

        CST(:, 4, t) = (OPCAP.*PP(:, 12).*F(:, t))* 365 * 24 / 1e12;

        % Total Electricity Generation Cost

        Cost(1, t) = sum(CST(:, 1, t)) + sum(CST(:, 2, t)) + sum(CST(:, 3, t)) + sum(CST(:, 4, t));

        

    % Damage Cost  (Billion$)

        Cost(2, t) = exp(10 * S(5 * n + 1, t + 1));               

end



CCON(:, :) = CST(:, 1, :);

CFOP(:, :) = CST(:, 2, :);

CVOP(:, :) = CST(:, 3, :);

CF(:, :) = CST(:, 4, :);