clc

clear;



global  PP D EM S Concentration T E_CONC n lambda CST Cost F CapFac

global  b CCR ER CCCOAL ECOAL prd ndbl nd CCR0 ER0 aCC aE



%   T = Total Time horizon(year)

    T = 50; 

    

%   POWER PLANTS



    % number of technologies

        n = 8;

        % 1: Coal (Single Unit Advanced PC)

        % 2: Natural Gas (Conventional CC)

        % 3: Nuclear

        % 4: Solar PV

        % 5: Wind (Onshore)

        % 6: Solar Thermal

        % 7: CCS (Coal Single Unit Advanced PC with CCS)

        % 8: Hydro



    PP = zeros(n, 12);    

    % Power generation options

        % PP(i, 1): Capital cost ($/KW)

        % PP(i, 2): Fixed O&M cost ($/KW)

        % PP(i, 3): Variable O&M cost ($/MWh)

        % PP(i, 4): Construction period (Lead time) (year)

        % PP(i, 5): Operation period (year)

        % PP(i, 6): Construction Emission CO2 (ton/MW)

        % PP(i, 7): Construction Emission CH4 (ton/MW)

        % PP(i, 8): Construction Emission N2O (ton/MW)

        % PP(i, 9): Operation Emission CO2 (ton/MW/year)

        % PP(i, 10): Operation Emission CH4 (ton/MW/year)

        % PP(i, 11): Operation Emission N2O (ton/MW/year)

        % PP(i, 12): Heat Rate (Btu/kWh)

      

        PP(:, 1) = [3246 917 5530 3873 2213 5067 5227 2936];

        PP(:, 2) = [37.8 13.17 93.28 24.69 39.55 67.26 80.53 14.13];

        PP(:, 3) = [4.47 3.60 2.14+5.6 0 0 0 9.51 0];

        PP(:, 4) = [4 3 5 2 4 2 4 4];

        PP(:, 5) = [40 30 35 20 30 20 40 100];

        PP(:, 6) = [202 762 36700 17400 32500 37300 4630 788];

        PP(:, 7) = [0.006171 0 0 0.533 0 0 0 0.0578];

        PP(:, 8) = [0.009344 0 0 0.478 0 0 0 0.0451];

        PP(:, 9) = [6590 5300 666 0 0 0 1750 0];

        PP(:, 10) = [1.21 0 0 0 0 0 13.2 0];

        PP(:, 11) = [0.582422 0 0 0 0 0 7.36 0];

        PP(:, 12) = [8800 7050 0 0 0 0 12000 0];

        

    % Learning factors

        CCCOAL = PP(1, 1);

        ECOAL = PP(1, 9);



        CCR0 = PP(:, 1) / CCCOAL;

        ER0 = PP(:, 6) / ECOAL;

        CCR = ones(n, T);

        CCR(:, 1) = CCR0;

        ER = ones(n, T);

        ER(:, 1) = ER0;

        

        % Learning Rate

        LR = [0 0 0.05 0 0 0.2 0.2 0;

              0 0 0.03 0.1 0 0.1 0.1 0;

              0.01 0.01 0.01 0.01 0.01 0.01 0.01 0.01];

        b = -log(1 - LR) / log(2);

        aCC = zeros(n, T);

        aE = zeros(n, T);  

        % Number of doubling in each period  

        nd = [0 0 3 0 0 3 3 0; 0 0 5 5 0 5 5 0];

        

        % EIA - International Energy Outlook 2013

        EIA = xlsread('EIA.xlsx');

        % Net Capacity

        D = EIA(1:8, :)/0.00876;

        CapFac = EIA(9:16, :);

                

%	CONCENTRATIONS

    % Concentration(i, 1): CO2 concentration (ton)

    % Concentration(i, 2): CH4 concentration (ton)

    % Concentration(i, 3): N2O concentration (ton)

  

    E_CONC = zeros(3, T);

    Concentration = zeros(3, T);

    for i = 0:1:T - 1

        j = i + 1;

        Concentration(1, j) = 0.217 + 0.259 * exp(-i / 172.9) + 0.338 * exp(-i / 18.51) + 0.186 * exp (-i/ 1.186);

        Concentration(2, j) = exp(-i / 12);  

        Concentration(3, j) = exp(-i / 114);

    end



%	EMISSIONS

    % Em(1, i): CO2 emissions from Electricity sources(Mt)

    % Em(2, i): CH4 emissions from Electricity sources(Mt)

    % EM(3, i): N2O emissions from Electricity sources(Mt)

        % Global Warming Potential (GWP): 

        % http://www.ipcc.ch/publications_and_data/ar4/wg1/en/tssts-2-5.html

        % CH4 GWP = 25 (for 100 years)

        % N2O GWP =  298 (for 100 years)

    EM = zeros (3, T);

    

%   STATE SPACE

    % S: State

        % 1:n Under_Construction Capacity New

        % n+1:2n Under_Construction Capacity Old

        % 2n+1:3n Operating Capacity New

        % 3n+1:4n Operating Capacity Old

        % 4n+1:5n Total built capacity (gross)

        % 5n+1 Atmospheric Temperature "Tat" at time t

        S = zeros(5 * n + 1, T);

    % Initial State        

        S(1 + 2 * n:3 * n, 1) = max(1, D(:, 1));

        % Installed Capacity: 

          % Solar, Wind, Hydro: http://www.worldenergy.org/data/resources/

          % Nuclear: http://www.world-nuclear.org/info/Facts-and-Figures/World-Nuclear-Power-Reactors-and-Uranium-Requirements/

          % Coal: http://www.iea-etsap.org/web/E-TechDS/PDF/E01-coal-fired-power-GS-AD-gct.pdf

          % Natural Gas: 

        S(1 + 4 * n:5 * n, 1) = [3e6 1e5 4e5 8.0e4 3.3e5 1 1 1.3e6];

        

%   ACTION SPACE

    Action = zeros(n, T);        

    act0 = zeros(T * n, 1);

    A = zeros(T, T * n);

    init = xlsread('init.xlsx');

    %   Constraints

    lb = 0.001 * ones(T*n, 1);

    ub = 1 * ones(T*n, 1);

    for i = 1:1:T

        A(i, (i-1) * n + 1:i * n)= 1;

        act0((i-1) * n + 1:i * n) = init(:, i);

        %act0((i-1) * n + 1:i * n) = 1/n * ones(n, 1);

        %ub((i-1) * n + 1:(i-1) * n + 3) = 0.5;

        %ub((i-1) * n + 4:(i-1) * n + 7) = min(0.1, i/100);

        ub(i * n) = 0.1;

    end

    

%   Costs

    % Discount rate

    lambda = 1/(1+0.1);

    % Fuel Costs

    F = xlsread('Fuel.xlsx');

    F = F(2:end, 2:end);

    % Construction, O&M, and Fuel Costs

    CST = zeros(n, 4, T);

        % Construction Costs

        CCON = zeros(n, T);

        % Fixed Operation Costs

        CFOP = zeros(n, T);

        % Variable Operation Costs

        CVOP = zeros(n, T);

        % Fuel Costs

        CF = zeros(n, T); 

    % Generation and Emission Costs

    Cost = zeros(2, T);

% interior-point sqp active-set

myoptions = optimset('Display','iter','FunValCheck','on','algorithm','sqp', 'MaxFunEvals', 1e5, 'TolX', 1e-9, 'TolCon', 1e-6, 'TolFun', 1e-4);

[aopt, fval] = fmincon(@E_fun,act0,[],[],A,ones(T,1),lb,ub, [], myoptions);

for j = 1:1:T

    Action(:,j) = aopt((j-1) * n + 1:j * n);

end

fval

CCON(:, :) = CST(:, 1, :);

CFOP(:, :) = CST(:, 2, :);

CVOP(:, :) = CST(:, 3, :);

CF(:, :) = CST(:, 4, :);