function [ force ] = FORCE( Emass )

%Radiative Forcing due to emissions

%   Detailed explanation can be found here

    % http://chartsgraphs.wordpress.com/2009/09/11/co2-emissions-changes-in-atmospheric-levels/

    % http://www.epa.gov/athens/learn2model/part-two/onsite/ia_unit_conversion_detail.html

    % http://www.grida.no/publications/other/ipcc_tar/?src=/climate/ipcc_tar/wg1/222.htm#635

    

% CO2

m1 = Emass(1) / 7820 + 400;

f1 = 3.35 * log((1 + 1.2 * m1 + 0.005 * m1^2 + 1.4 * 10^-6 * m1^3) / (1 + 1.2 * 400 + 0.005 * 400^2 + 1.4 * 10^-6 * 400^3));



% CH4

m2 = Emass(2) / 2.844 + 1800;

f2 = 0.036 * (sqrt(m2) - sqrt(1800)) - 0.47 * log(1 + 2.01 * 10^-5 * (m2 * 320)^0.75 + 5.31 * 10^-15 * m2 * (m2 * 320)^1.52) + 0.47 * log(1 + 2.01 * 10^-5 * (1800 * 320)^0.75 + 5.31 * 10^-15 * 1800 * (1800 * 320)^1.52);



% N2O

m3 = Emass(3) / 7.820 + 320;

f3 = 0.12 * (sqrt(m3) - sqrt(320)) - 0.47 * log(1 + 2.01 * 10^-5 * (1800 * m3)^0.75 + 5.31 * 10^-15 * 1800 * (1800 * m3)^1.52) + 0.47 * log(1 + 2.01 * 10^-5 * (1800 * 320)^0.75 + 5.31 * 10^-15 * 1800 * (1800 * 320)^1.52);



force = f1 + f2 + f3;



end



