%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Script to solve the heat equation in ocean with %%%

%%% temperature forcing                             %%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ Tempchange ] = TEMP( T2, deltaF2 )



%%% Initial variables

dz = 20; % each depth step is 10 meter

Nz = 200; % Choose the number of depth steps

Nt = 12 * 1 ; % Choose the number of time steps (number of months)

dt = (1 * 365 * 24 * 60 * 60)/Nt; % Length of each time step in seconds (~ 1 day)

K =  5.5 * 10^-5; % thermal diffusivity (m2 sec-1)

ro = 1030; % density of seawater (kg m-3) (http://web.mit.edu/seawater/Seawater_Property_Tables.pdf)

c = 4000; % heat capacity of seawater (J kg-1 K-1) (http://web.mit.edu/seawater/Seawater_Property_Tables.pdf)

f = 0.7; % fraction of the earth covered by ocean

F = deltaF2; % change in radiative forcing (W m-2)

lambda = 3.8/3; % feedback parameter (W m2 K-1)

a = (ro * K * f * c);

Tem = zeros(Nz + 1, Nt + 1);  %Create temperature change matrix with Nz+1 rows, and Nt+1 columns

                                % Initial guess is that T is T0 everywhere.

maxiter = 500;

err = zeros(1, maxiter);

ksi = 2 * K * dt / dz^2;



for iter = 1:maxiter

    Tlast = Tem; %Save the last guess

    Tem(:, 1) = T2; %Initialize the temp at t=0 to the last temp

    for t = 2:Nt + 1,

        for z = 1:Nz - 1

            depth_2D = (Tem(z, t - 1) - 2 * Tem(z + 1, t - 1) + Tem(z + 2, t - 1)) / dz^2;

            time_1D = K * depth_2D;

            Tem(z + 1, t) = time_1D * dt + Tem(z + 1, t - 1);   

        end

        Tem(end, t) = Tem(end - 1, t); % Enforce bottom BC

        depth_1D = (lambda * Tem(1, t) - F) / a;

        Tem(1, t) = Tem(2, t) - depth_1D * dz; % Enforce top BC 

    end

    err(iter) = max(abs(Tem(:) - Tlast(:)));  %Find difference between last two solutions

    if err(iter) < 1E-4

        break; % Stop if solutions very similar, we have convergence

    end

end



Tempchange = Tem(1, Nt + 1);